@@ -5,17 +5,16 @@ from Products.Archetypes.public import BooleanWidget
 from interfaces import IFormSaveData2ContentEntry
 from Acquisition import aq_parent, aq_inner
 from Products.Archetypes.Field import TextField, StringField, DateTimeField, \
-    FixedPointField, FileField, LinesField, IntegerField, ObjectField
+    FixedPointField, FileField, LinesField, IntegerField, ObjectField, \
+    BooleanField
 from Products.PloneFormGen.content.fieldsBase import LinesVocabularyField, \
     StringVocabularyField
-from Products.PloneFormGen.content.likertField import LikertField
-from Products.PloneFormGen.content.fields import HtmlTextField, NRBooleanField, \
-    PlainTextField
-    
-from archetypes.schemaextender.field import ExtensionField
+from Products.PloneFormGen.content.fields import HtmlTextField, PlainTextField
 
+from archetypes.schemaextender.field import ExtensionField
 from plone.memoize.instance import memoize
 
+
 class XPlainTextField(ExtensionField, PlainTextField): pass
 class XTextField(ExtensionField, TextField): pass
 class XStringField(ExtensionField, StringField): pass
@@ -24,41 +23,71 @@ class XFixedPointField(ExtensionField, FixedPointField): pass
 class XFileField(ExtensionField, FileField): pass
 class XLinesField(ExtensionField, LinesField): pass
 class XIntegerField(ExtensionField, IntegerField): pass
+class XBooleanField(ExtensionField, BooleanField): pass
 
 class XLinesVocabularyField(ExtensionField, LinesVocabularyField): pass
 class XStringVocabularyField(ExtensionField, StringVocabularyField): pass
-
-class XLikertField(ExtensionField, LikertField): 
-    """
-    override default methods which have bugs...
-    """
-    
-    def get(self, instance, **kwargs):
-        value = ObjectField.get(self, instance, **kwargs)
-        if not value:
-            return tuple()
-        else:
-            return value
-
-    def set(self, instance, value, **kwargs):
-        if type(value) in (str, unicode):
-            value = [v.strip() for v in value.split(',')]
-        ObjectField.set(self, instance, value, **kwargs)
-
-
 class XHtmlTextField(ExtensionField, HtmlTextField): pass
-class XNRBooleanField(ExtensionField, NRBooleanField): pass
-    
+
 extension_fields = [
     XTextField, XStringField, XDateTimeField, XFixedPointField, XFileField,
     XLinesField, XIntegerField, XLinesVocabularyField, XStringVocabularyField,
-    XLikertField, XHtmlTextField, XNRBooleanField, XPlainTextField
+    XHtmlTextField, XPlainTextField
 ]
 
+# XXX
+# begin backwards compatible imports
+# XXX
+try:
+    from Products.PloneFormGen.content.fields import NRBooleanField as BooleanField
+    class XNRBooleanField(ExtensionField, BooleanField): pass
+    extension_fields.append(XNRBooleanField)
+except:
+    pass
+
+try:
+    from Products.PloneFormGen.content.likertField import LikertField
+    def get_likert(self, instance, **kwargs):
+        value = ObjectField.get(self, instance, **kwargs)
+        if not value:
+            return {}
+        else:
+            return value
+
+    def set_likert(self, instance, value, **kwargs):
+        if type(value) in (str, unicode):
+            value = [v.strip() for v in value.split(',')]
+        elif type(value) in (tuple, list, set):
+            newval = {}
+            for i in range(0, len(value)):
+                newval[str(i+1)] = value[i]
+            value = newval
+                
+        ObjectField.set(self, instance, value, **kwargs)
+        
+    class XLikertField(ExtensionField, LikertField): 
+        """
+        override default methods which have bugs...
+        """
+
+        get = get_likert
+        set = set_likert
+            
+    # patch these methods to actually work.
+    LikertField.get = get_likert
+    LikertField.set = set_likert
+    extension_fields.append(XLikertField)       
+except:
+    pass
+
+# extra field attributes to copy over.
 extra_fields = [
     'widget', 'questionSet', 'answerSet', 'validators'
 ]
 
+# instance values to copy over
+instance_values_to_field = ['minval', 'maxval']
+
 FIELDS = {}
 
 for klass in extension_fields:
@@ -78,10 +107,11 @@ class ContentEntryExtender(object):
     @memoize
     def getFields(self):
         form = aq_parent(aq_parent(aq_inner(self.context)))
-        obj_fields = form.fgFields()
+        obj_fields = form._getFieldObjects()
         fields = []
         
-        for field in obj_fields:
+        for objfield in obj_fields:
+            field = objfield.fgField
             klassname = 'X' + field.__class__.__name__
             if FIELDS.has_key(klassname):
                 klass = FIELDS[klassname]
@@ -90,6 +120,11 @@ class ContentEntryExtender(object):
                     if hasattr(field, key):
                         setattr(newfield, key, getattr(field, key))
                         
+                for val in instance_values_to_field:
+                    if objfield.schema.has_key(val):
+                        valfield = objfield.schema.get(val)
+                        setattr(newfield, val, valfield.get(objfield))
+                
                 fields.append(newfield)
             
         return fields
\ No newline at end of file
